diff --git a/FL/Fl_Browser.H b/FL/Fl_Browser.H
index 4c4521d..d5f7639 100644
--- a/FL/Fl_Browser.H
+++ b/FL/Fl_Browser.H
@@ -3,7 +3,7 @@
 //
 // Browser header file for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2011 by Bill Spitzak and others.
+// Copyright 1998-2015 by Bill Spitzak and others.
 //
 // This library is free software. Distribution and use rights are outlined in
 // the file "COPYING" which should have been included with this file.  If this
@@ -132,6 +132,7 @@ public:
   int  load(const char* filename);
   void swap(int a, int b);
   void clear();
+  void resize(int,int,int,int);
 
   /**
     Returns how many lines are in the browser.
diff --git a/FL/Fl_Browser_.H b/FL/Fl_Browser_.H
index 8fb22ca..9bf9e0f 100644
--- a/FL/Fl_Browser_.H
+++ b/FL/Fl_Browser_.H
@@ -302,7 +302,12 @@ public:
   /**
     Sets the default text size (in pixels) for the lines in the browser to \p size.
   */
-  void textsize(Fl_Fontsize newSize) { textsize_ = newSize; }
+  void textsize(Fl_Fontsize newSize) {
+    textsize_ = newSize;
+    max_width_item = 0;		// force recalculation (STR #3057)
+    max_width = 0;
+    resize(x(),y(),w(),h());	// *FIXME* this is kinda brute force (POC)
+  }
 
   /**
     Gets the default text color for the lines in the browser.
diff --git a/src/Fl_Browser.cxx b/src/Fl_Browser.cxx
index c81c88e..7e1c9b9 100644
--- a/src/Fl_Browser.cxx
+++ b/src/Fl_Browser.cxx
@@ -3,7 +3,7 @@
 //
 // Browser widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2010 by Bill Spitzak and others.
+// Copyright 1998-2015 by Bill Spitzak and others.
 //
 // This library is free software. Distribution and use rights are outlined in
 // the file "COPYING" which should have been included with this file.  If this
@@ -129,6 +129,22 @@ const char *Fl_Browser::item_text(void *item) const {
 }
 
 /**
+  Resizes the Fl_Browser widget.
+
+  Internal (cached) values are recalculated so the scrollbars will be
+  adjusted when the next draw() is done.
+*/
+void Fl_Browser::resize(int X, int Y, int W, int H) {
+  Fl_Browser_::resize(X,Y,W,H);
+  full_height_ = 0;
+  if (size() < 1) return;
+  FL_BLINE* itm;
+  for (itm=(FL_BLINE *)item_first(); itm; itm=(FL_BLINE *)item_next(itm)) {
+    full_height_ += item_height(itm);
+  }
+}
+
+/**
   Returns the item for specified \p line.
 
   Note: This call is slow. It's fine for e.g. responding to user
diff --git a/src/Fl_Browser_.cxx b/src/Fl_Browser_.cxx
index a85fc01..1da89bb 100644
--- a/src/Fl_Browser_.cxx
+++ b/src/Fl_Browser_.cxx
@@ -3,7 +3,7 @@
 //
 // Base Browser widget class for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2010 by Bill Spitzak and others.
+// Copyright 1998-2015 by Bill Spitzak and others.
 //
 // This library is free software. Distribution and use rights are outlined in
 // the file "COPYING" which should have been included with this file.  If this
@@ -113,6 +113,8 @@ void Fl_Browser_::resize(int X, int Y, int W, int H) {
   hscrollbar.resize(
 	X, scrollbar.align()&FL_ALIGN_TOP ? Y-scrollsize : Y+H,
 	W, scrollsize);
+  // max_width = 0; // force recalculation of internals (STR #3057)
+  // *FIXME* not necessary for scrollbar adjustments ?  (STR #3057)
 }
 
 // Cause minimal update to redraw the given item:
